Connectivity query for yakuba neurons
Arguments
- ids
A set of body ids (see
dyak_ids()for a range of ways to specify these).- partners
Either inputs or outputs. Redundant with
prepost, but probably clearer.- moredetails
Either a logical (to add all fields when
TRUE) or a character vector naming additional fields returned bydyak_neuprint_meta()that will be added to the results data frame.- summary
When
TRUEand more than one query neuron is given, summarises connectivity grouped by partner.- threshold
Only return partners >= to an integer value. Default of 1 returns all partners. This threshold will be applied to the ROI weight when the
roiargument is specified, otherwise to the whole neuron.- roi
a single ROI. Use
neuprint_ROIsto see what is available.- by.roi
logical, whether or not to break neurons' connectivity down by region of interest (ROI)
- conn
Optional, a
neuprint_connectionobject. Defaults todyak_neuprint()to ensure that query is against the yakuba dataset.- ...
Additional arguments passed to
neuprintr::neuprint_connection_table().- dataset
The name of the dataset as reported in Clio e.g.
yakuba,yakuba-vncetc.yakuba,yakuba-vncandyakubavncare treated as aliases for the main yakuba dataset.
Examples
# \donttest{
dyak_connection_table("DNa02", partners = "outputs")
#> Error in (function (path, body = NULL, server = NULL, conf = NULL, parse.json = TRUE, include_headers = TRUE, simplifyVector = FALSE, app = NULL, ...) { if (is.null(app)) app = paste0("neuprintr/", utils::packageVersion("neuprintr")) req <- if (is.null(body)) { httr::GET(url = file.path(server, path, fsep = "/"), config = conf, httr::user_agent(app), ...) } else { httr::POST(url = file.path(server, path, fsep = "/"), body = body, config = conf, httr::user_agent(app), ...) } neuprint_error_check(req) if (parse.json) { parsed = neuprint_parse_json(req, simplifyVector = simplifyVector) if (length(parsed) == 2 && isTRUE(names(parsed)[2] == "error")) { stop("neuPrint error: ", parsed$error) } if (include_headers) { fields_to_include = c("url", "headers") attributes(parsed) = c(attributes(parsed), req[fields_to_include]) } parsed } else req})(path = path, body = body, server = server, conf = conf, parse.json = parse.json, include_headers = include_headers, simplifyVector = simplifyVector, app = app): Unauthorized (HTTP 401). Failed to process url: https://neuprint-yakuba.janelia.org/api/dbmeta/datasets with neuPrint error: invalid or expired jwt.
dyak_connection_table("DNa02", partners = "outputs", summary = TRUE)
#> Error in (function (path, body = NULL, server = NULL, conf = NULL, parse.json = TRUE, include_headers = TRUE, simplifyVector = FALSE, app = NULL, ...) { if (is.null(app)) app = paste0("neuprintr/", utils::packageVersion("neuprintr")) req <- if (is.null(body)) { httr::GET(url = file.path(server, path, fsep = "/"), config = conf, httr::user_agent(app), ...) } else { httr::POST(url = file.path(server, path, fsep = "/"), body = body, config = conf, httr::user_agent(app), ...) } neuprint_error_check(req) if (parse.json) { parsed = neuprint_parse_json(req, simplifyVector = simplifyVector) if (length(parsed) == 2 && isTRUE(names(parsed)[2] == "error")) { stop("neuPrint error: ", parsed$error) } if (include_headers) { fields_to_include = c("url", "headers") attributes(parsed) = c(attributes(parsed), req[fields_to_include]) } parsed } else req})(path = path, body = body, server = server, conf = conf, parse.json = parse.json, include_headers = include_headers, simplifyVector = simplifyVector, app = app): Unauthorized (HTTP 401). Failed to process url: https://neuprint-yakuba.janelia.org/api/dbmeta/datasets with neuPrint error: invalid or expired jwt.
# }