Check if a bodyid still exists in the specified yakuba DVID node
Source:R/bodies.R
dyak_islatest.RdCheck if a bodyid still exists in the specified yakuba DVID node
Usage
dyak_islatest(
ids,
node = "neutu",
method = c("auto", "size", "sparsevol"),
dataset = dyak_default_dataset()
)Arguments
- ids
A set of body ids in any form understandable to
manc_ids- node
A DVID node (defaults to the current neutu node, see
manc_dvid_node)- method
Which DVID endpoint to use. Expert use only.
- dataset
The name of the dataset as reported in Clio or neuprint.
Details
For details (and there are some) please see
malevnc::manc_islatest().
Examples
# \donttest{
dyak_islatest(c(10280,10490))
#> [1] TRUE TRUE
# }